This constructs a flow object and put in the flow scdb. Flow themselves are NULL by default, use gen_mincost to compute them.

mcell_new_mctnetflow(
  flow_id,
  net_id,
  init_mincost = F,
  flow_tolerance = 0.01,
  flows = NULL
)

Arguments

flow_id

id of scdb network object ot be added

net_id

id of scdb mc time network object

init_mincost

TRUE if you want to compute flows using the mincost algorith

flows

flows per network edge (NULL by default, if not NULL it will supress the init_mincost flag)