This generate two large matrices showing expression of genes per metacell ad time point, as well as the expression of the gene in inferred ancestral states given the flow model

mctnetflow_gen_e_gmt_p(mcf_id, mat_id, genes)

Arguments

mcf_id

mcf network object

mat_id

umi matrix object

genes

list of gene names

Value

A matrix on metacells and time with mean umi fraction over the gene module