Given a list of genes and a matrix, this compute mean umi per metacell (rows) and time (column).

mctnetflow_gen_gmod_mc_t(mcf_id, mat_id, genes, min_percentile = 0.05)

Arguments

mcf_id

flow object id

mat_id

umi matrix object

genes

list of gene names

min_percentile

percentile value to use as minimum threshold (this is used to avoid very small values and regularize color scale, default 0.05)

Value

A matrix on metacells and time with mean umi fraction over the gene module