Compute backward and forward flow propgation of metacell probability from time t

mctnetflow_propogate_from_t(mcf, t, mc_p)

Arguments

t

flows will be computed for the (time,time+1) interval

mc_p

probabilities at time t

mct

mct network object

Value

a list with two elements: probs is a matrix of probabilities over metacells (rows) and time (columns). step_m is a list of sparse matrices inferred flows between metacells per time.