mctnetflow_propogate_from_t.RdCompute backward and forward flow propgation of metacell probability from time t
mctnetflow_propogate_from_t(mcf, t, mc_p)flows will be computed for the (time,time+1) interval
probabilities at time t
mct network object
a list with two elements: probs is a matrix of probabilities over metacells (rows) and time (columns). step_m is a list of sparse matrices inferred flows between metacells per time.